'use strict';

var _FieldStore = require('../FieldStore');

var _FieldStore2 = _interopRequireDefault(_FieldStore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('#FieldStore', function () {
  var field = null;

  beforeEach(function () {
    field = new _FieldStore2.default({
      validate: function validate() {
        return null;
      },
      defaultValue: ''
    });
  });

  it('should initialize properly', function () {
    expect(field.value).toBe('');
    expect(field.visited).toBe(false);
    expect(field.touched).toBe(false);
    expect(field.active).toBe(false);
    expect(field.error).toBeNull();
    expect(field.dirty).toBe(false);
  });

  it('should return props', function () {
    expect(field.props).toEqual({
      value: '',
      visited: false,
      touched: false,
      active: false,
      error: null,
      dirty: false
    });
  });

  it('should have an error', function () {
    field.validate = function (value) {
      return value.length > 5 ? null : 'short';
    };

    expect(field.error).toBe('short');
  });

  it('should be dirty', function () {
    field.defaultValue = 'doge';

    expect(field.dirty).toBe(true);
  });
});