'use strict';

var _FormStore = require('../FormStore');

var _FormStore2 = _interopRequireDefault(_FormStore);

var _FieldStore = require('../FieldStore');

var _FieldStore2 = _interopRequireDefault(_FieldStore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.mock('../FieldStore');

describe('#FormStore', function () {
  var form = null;

  beforeEach(function () {
    form = new _FormStore2.default();
    form.fields = {
      field1: new _FieldStore2.default({ value: 'test', error: null }),
      fieldArray: [new _FieldStore2.default({ value: 'array1', error: 'short' })],
      fieldSections: [{ field: new _FieldStore2.default({ value: 'medium0', error: 'long' }) }, { field: new _FieldStore2.default({ value: 'medium1', error: null }) }]
    };
  });

  it('should return all values', function () {
    expect(form.values).toEqual({
      field1: 'test',
      fieldArray: ['array1'],
      fieldSections: [{ field: 'medium0' }, { field: 'medium1' }]
    });
  });

  it('should return all errors', function () {
    expect(form.errors).toEqual({
      field1: null,
      fieldArray: ['short'],
      fieldSections: [{ field: 'long' }, { field: null }]
    });
  });

  it('should mark a from as invalid', function () {
    expect(form.valid).toBe(false);
  });

  it('should add a field directly', function () {
    form.addField('', 'field2', new _FieldStore2.default());

    expect(form.fields.field2).toBeDefined();
  });

  it('should add a field deeply', function () {
    form.addField('fieldSections#1', 'field1', new _FieldStore2.default());

    expect(form.fields.fieldSections[1].field1).toBeDefined();
  });

  it('should add a field array directly', function () {
    form.addFieldArray('', 'field2');

    expect(form.fields.field2).toBeDefined();
  });

  it('should add a field array deeply', function () {
    form.addFieldArray('fieldSections#1', 'field1');

    expect(form.fields.fieldSections[1].field1).toBeDefined();
  });

  it('should remove a field directly', function () {
    form.removeField('', 'field1');

    expect(form.fields.field1).toBeUndefined();
  });

  it('should remove a field deeply', function () {
    form.removeField('fieldSections#1', 'field');

    expect(form.fields.fieldSections[1].field).toBeUndefined();
  });

  it('should map a field array', function () {
    var result = form.map('fieldArray', function (id) {
      return id;
    });

    expect(result).toEqual([0]);
  });

  it('should push an empty field', function () {
    form.push('fieldArray', null);

    expect(form.fields.fieldArray.length).toBe(2);
  });

  it('should push an object field', function () {
    form.push('fieldSections', {});

    expect(form.fields.fieldSections.length).toBe(3);
    expect(form.fields.fieldSections[2]).toEqual({});
  });

  it('should pop a field', function () {
    form.pop('fieldSections');

    expect(form.fields.fieldSections.length).toBe(1);
    expect(form.fields.fieldSections[0].field.value).toBe('medium0');
  });

  it('should unshift an empty field', function () {
    form.unshift('fieldArray', null);

    expect(form.fields.fieldArray.length).toBe(2);
  });

  it('should unshift an object field', function () {
    form.unshift('fieldSections', {});

    expect(form.fields.fieldSections.length).toBe(3);
    expect(form.fields.fieldSections[0]).toEqual({});
  });

  it('should shift a field', function () {
    form.shift('fieldSections');

    expect(form.fields.fieldSections.length).toBe(1);
    expect(form.fields.fieldSections[0].field.value).toBe('medium1');
  });
});