'use strict';

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _mapForm = require('../mapForm');

var _FieldStore = require('../../containers/FieldStore');

var _FieldStore2 = _interopRequireDefault(_FieldStore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.mock('../../containers/FieldStore');

var flat = {
  field1: new _FieldStore2.default({ value: 'flat0' }),
  field2: new _FieldStore2.default({ value: 'flat1' })
};

var medium = {
  field1: new _FieldStore2.default({ value: 'flat0' }),
  fieldArray: [{ field: new _FieldStore2.default({ value: 'medium0' }) }, { field: new _FieldStore2.default({ value: 'medium1' }) }],
  flatArray: [new _FieldStore2.default({ value: 'array0' }), new _FieldStore2.default({ value: 'array1' })]
};

var deep = {
  field1: new _FieldStore2.default({ value: 'flat0' }),
  fieldArray: [{
    field: new _FieldStore2.default({ value: 'medium0' }),
    nested: []
  }, {
    field: new _FieldStore2.default({ value: 'medium1' }),
    nested: [new _FieldStore2.default({ value: 'deep0' })]
  }]
};

describe('#mapDeep', function () {
  it('should map a flat form', function () {
    var result = (0, _mapForm.mapDeep)(_ramda2.default.prop('value'), flat);

    expect(result.field1).toBe('flat0');
    expect(result.field2).toBe('flat1');
  });

  it('should map a medium form', function () {
    var result = (0, _mapForm.mapDeep)(_ramda2.default.prop('value'), medium);

    expect(result.field1).toBe('flat0');
    expect(result.fieldArray[0].field).toBe('medium0');
    expect(result.fieldArray[1].field).toBe('medium1');
    expect(result.flatArray[0]).toBe('array0');
    expect(result.flatArray[1]).toBe('array1');
  });

  it('should map a deep form', function () {
    var result = (0, _mapForm.mapDeep)(_ramda2.default.prop('value'), deep);

    expect(result.field1).toBe('flat0');
    expect(result.fieldArray[0].field).toBe('medium0');
    expect(result.fieldArray[1].field).toBe('medium1');
    expect(result.fieldArray[1].nested[0]).toBe('deep0');
  });
});

describe('#mapFlat', function () {
  it('should map a flat form', function () {
    var result = (0, _mapForm.mapFlat)(_ramda2.default.prop('value'), flat);

    expect(result).toEqual(['flat0', 'flat1']);
  });

  it('should map a medium form', function () {
    var result = (0, _mapForm.mapFlat)(_ramda2.default.prop('value'), medium);

    expect(result).toEqual(['flat0', 'medium0', 'medium1', 'array0', 'array1']);
  });

  it('should map a deep form', function () {
    var result = (0, _mapForm.mapFlat)(_ramda2.default.prop('value'), deep);

    expect(result).toEqual(['flat0', 'medium0', 'medium1', 'deep0']);
  });
});