'use strict';

var _traverse = require('../traverse');

var _traverse2 = _interopRequireDefault(_traverse);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var flat = {
  group: { value: 'gym' },
  people: [{
    name: { value: 'test' }
  }, {
    name: { value: 'test2' }
  }]
};

var deep = {
  doges: [{
    name: { value: 'doge' },
    foods: [{
      name: { value: 'meat' },
      types: [{ value: 'steak' }, { value: 'wing' }]
    }]
  }]
};

describe('#traverse', function () {
  it('should return root if no context supplied', function () {
    var result = (0, _traverse2.default)(flat, '');

    expect(result).toEqual(flat);
  });

  it('should find a member in flat fields', function () {
    var result = (0, _traverse2.default)(flat, 'group');

    expect(result).toEqual(flat.group);
  });

  it('should find fields in flat fields', function () {
    var result = (0, _traverse2.default)(flat, 'people#1');

    expect(result).toEqual(flat.people[1]);
  });

  it('should not find fields in flat fields', function () {
    var result = (0, _traverse2.default)(flat, 'people#2');

    expect(result).toBeNull();
  });

  it('should find fields in deep fields', function () {
    var result = (0, _traverse2.default)(deep, 'doges#0.foods#0.types#1');

    expect(result).toEqual(deep.doges[0].foods[0].types[1]);
  });

  it('should find a member in deep fields', function () {
    var result = (0, _traverse2.default)(deep, 'doges#0.foods');

    expect(result).toEqual(deep.doges[0].foods);
  });

  it('should not find fields in deep fields', function () {
    var result = (0, _traverse2.default)(deep, 'doges#0.people#0.nutrition#1');

    expect(result).toBeNull();
  });
});